@@ -25,10 +25,10 @@
 #include "utils.h"
 #include "davresource_debug.h"
 
-#include <klineedit.h>
+#include <KLineEdit>
 #include <KLocalizedString>
 
-#include <kwallet.h>
+#include <KWallet>
 
 #include <KDAV/ProtocolInfo>
 
