@@ -43,7 +43,7 @@ using namespace Mock;
 #include "ewspkeyauthjob.h"
 #endif
 #endif
-#include <qtwebenginewidgetsversion.h>
+#include <QtWebEngineWidgetsVersion>
 #include "ewsclient_debug.h"
 
 static const auto o365AuthorizationUrl = QUrl(QStringLiteral("https://login.microsoftonline.com/common/oauth2/authorize"));
@@ -158,12 +158,17 @@ public:
 
 void EwsOAuthUrlSchemeHandler::requestStarted(QWebEngineUrlRequestJob *request)
 {
-    returnUriReceived(request->requestUrl());
+    Q_EMIT returnUriReceived(request->requestUrl());
 }
 
 void EwsOAuthReplyHandler::networkReplyFinished(QNetworkReply *reply)
 {
-    if (reply->error() != QNetworkReply::NoError) {
+#if (QT_VERSION < QT_VERSION_CHECK(5, 15, 0))
+    const auto networkError = reply->error();
+#else
+    const auto networkError = reply->networkError();
+#endif
+    if (networkError != QNetworkReply::NoError) {
         Q_EMIT replyError(reply->errorString());
         return;
     } else if (reply->header(QNetworkRequest::ContentTypeHeader).isNull()) {
@@ -231,7 +236,7 @@ void EwsOAuthRequestInterceptor::interceptRequest(QWebEngineUrlRequestInfo &info
         ) {
         qCDebug(EWSCLI_LOG) << QStringLiteral("Found redirect URI - blocking request");
 
-        redirectUriIntercepted(url);
+        Q_EMIT redirectUriIntercepted(url);
         info.block(true);
     }
 }
@@ -351,7 +356,8 @@ QVariantMap EwsOAuthPrivate::queryToVarmap(const QUrl &url)
 {
     QUrlQuery query(url);
     QVariantMap varmap;
-    for (const auto &item : query.queryItems()) {
+    const auto items = query.queryItems();
+    for (const auto &item : items) {
         varmap[item.first] = item.second;
     }
     return varmap;
@@ -378,7 +384,7 @@ void EwsOAuthPrivate::redirectUriIntercepted(const QUrl &url)
         return;
     }
 #endif
-    mOAuth2.authorizationCallbackReceived(queryToVarmap(url));
+    Q_EMIT mOAuth2.authorizationCallbackReceived(queryToVarmap(url));
 }
 
 #ifdef HAVE_QCA
@@ -393,7 +399,7 @@ void EwsOAuthPrivate::pkeyAuthResult(KJob *j)
     } else {
         varmap[QStringLiteral("error")] = job->errorString();
     }
-    mOAuth2.authorizationCallbackReceived(varmap);
+    Q_EMIT mOAuth2.authorizationCallbackReceived(varmap);
 }
 
 #endif
@@ -440,7 +446,7 @@ EwsOAuth::~EwsOAuth()
 
 void EwsOAuth::init()
 {
-    requestWalletMap();
+    Q_EMIT requestWalletMap();
 }
 
 bool EwsOAuth::getAuthData(QString &username, QString &password, QStringList &customHeaders)
