@@ -39,7 +39,11 @@ static const QMap<QString, QCA::CertificateInfoTypeKnown> stringToKnownCertInfoT
 static QMultiMap<QCA::CertificateInfoType, QString> parseCertSubjectInfo(const QString &info)
 {
     QMultiMap<QCA::CertificateInfoType, QString> map;
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     for (const auto &token : info.split(QLatin1Char(','), QString::SkipEmptyParts)) {
+#else
+    for (const auto &token : info.split(QLatin1Char(','), Qt::SkipEmptyParts)) {
+#endif
         const auto keyval = token.trimmed().split(QLatin1Char('='));
         if (keyval.count() == 2) {
             if (stringToKnownCertInfoType.contains(keyval[0])) {
@@ -110,7 +114,12 @@ void EwsPKeyAuthJob::sendAuthRequest(const QByteArray &respToken, const QUrl &su
 
 void EwsPKeyAuthJob::authRequestFinished()
 {
-    if (mAuthReply->error() == QNetworkReply::NoError) {
+#if (QT_VERSION < QT_VERSION_CHECK(5, 15, 0))
+    const auto networkError = mAuthReply->error();
+#else
+    const auto networkError = mAuthReply->networkError();
+#endif
+    if (networkError == QNetworkReply::NoError) {
         mResultUri = mAuthReply->attribute(QNetworkRequest::RedirectionTargetAttribute).toUrl();
         if (!mResultUri.isValid()) {
             setErrorMsg(QStringLiteral("Incorrect or missing redirect URI in PKeyAuth response"));
