@@ -34,7 +34,7 @@
 #include <KCalendarCore/ICalFormat>
 #include <KCalendarCore/MemoryCalendar>
 #include <changerecorder.h>
-#include <kdbusconnectionpool.h>
+#include <QDBusConnection>
 #include <entitydisplayattribute.h>
 #include <collectionfetchjob.h>
 #include <collectionfetchscope.h>
@@ -44,7 +44,7 @@
 #include <itemdeletejob.h>
 #include <itemmodifyjob.h>
 
-#include <kdirwatch.h>
+#include <KDirWatch>
 #include <KLocalizedString>
 
 #include <QDir>
@@ -63,9 +63,9 @@ static const char warningFile[] = "WARNING_README.txt";
 
 #define DEBUG_DATA(func) \
     qCDebug(KALARMDIRRESOURCE_LOG)<<func<<"ID:Files:"; \
-    foreach (const QString &id, mEvents.uniqueKeys()) { qCDebug(KALARMDIRRESOURCE_LOG)<<id<<":"<<mEvents[id].files; } \
+    foreach (const QString &id, mEvents.keys()) { qCDebug(KALARMDIRRESOURCE_LOG)<<id<<":"<<mEvents[id].files; } \
     qCDebug(KALARMDIRRESOURCE_LOG)<<"File:IDs:"; \
-    foreach (const QString &f, mFileEventIds.uniqueKeys()) { qCDebug(KALARMDIRRESOURCE_LOG)<<f<<":"<<mFileEventIds[f]; }
+    foreach (const QString &f, mFileEventIds.keys()) { qCDebug(KALARMDIRRESOURCE_LOG)<<f<<":"<<mFileEventIds[f]; }
 
 KAlarmDirResource::KAlarmDirResource(const QString &id)
     : ResourceBase(id)
@@ -80,7 +80,7 @@ KAlarmDirResource::KAlarmDirResource(const QString &id)
 
     // Set up the resource
     new KAlarmDirSettingsAdaptor(mSettings);
-    KDBusConnectionPool::threadConnection().registerObject(QStringLiteral("/Settings"),
+    QDBusConnection::sessionBus().registerObject(QStringLiteral("/Settings"),
                                                            mSettings, QDBusConnection::ExportAdaptors);
     connect(mSettings, &Akonadi_KAlarm_Dir_Resource::Settings::configChanged, this, &KAlarmDirResource::settingsChanged);
 
