@@ -28,8 +28,7 @@ class KolabMessageHelper : public MessageHelper
 public:
     explicit KolabMessageHelper(const Akonadi::Collection &collection);
     ~KolabMessageHelper() override;
-    Akonadi::Item createItemFromMessage(const KMime::Message::Ptr &message, const qint64 uid, const qint64 size, const QMap<QByteArray, QVariant> &attrs, const QList<QByteArray> &flags,
-                                        const KIMAP::FetchJob::FetchScope &scope, bool &ok) const override;
+    Akonadi::Item createItemFromMessage(const KMime::Message::Ptr &message, const qint64 uid, const qint64 size, const QMap<QByteArray, QVariant> &attrs, const QList<QByteArray> &flags, const KIMAP::FetchJob::FetchScope &scope, bool &ok) const override;
 
 private:
     Akonadi::Collection mCollection;
