@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2007 Till Adam <adam@kde.org>
+    Copyright (c) 2015 Daniel Vrátil <dvratil@redhat.com>
 
     This library is free software; you can redistribute it and/or modify it
     under the terms of the GNU Library General Public License as published by
@@ -19,8 +19,4 @@
 
 #include "maildirresource.h"
 
-#include <akonadi/agentfactory.h>
-
-#include <QtCore/QtPlugin>
-
-AKONADI_AGENT_FACTORY( MaildirResource, akonadi_maildir_resource )
+AKONADI_RESOURCE_MAIN(MaildirResource)
