@@ -32,7 +32,6 @@ namespace KWallet {
 class Wallet;
 }
 
-class POP3Resource;
 class KJob;
 
 class AccountWidget : public QWidget, private Ui::PopPage
@@ -57,7 +56,7 @@ private Q_SLOTS:
     void slotEnableLeaveOnServerSize(bool state);
     void slotFilterOnServerClicked();
     void slotPipeliningClicked();
-    void slotPopEncryptionChanged(int);
+    void slotPopEncryptionChanged(QAbstractButton *button);
     void slotCheckPopCapabilities();
     void slotPopCapabilities(const QVector<int> &);
     void slotLeaveOnServerDaysChanged(int value);
