@@ -37,8 +37,8 @@
 #include <kio/job.h>
 #include <KPasswordDialog>
 #include <KMessageBox>
-#include <knotification.h>
-#include <kwallet.h>
+#include <KNotification>
+#include <KWallet>
 #include "pop3resource_debug.h"
 
 #include <QTimer>
@@ -715,7 +715,11 @@ QList<int> POP3Resource::shouldDeleteId(int downloadedId) const
             mIdsToSaveValid = true;
             mIdsToSave.clear();
 
+#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
             const QSet<int> idsOnServer = QSet<int>::fromList(idsToDeleteFromServer);
+#else
+            const QSet<int> idsOnServer(idsToDeleteFromServer.constBegin(), idsToDeleteFromServer.constEnd());
+#endif
 
             // If the time-limited leave rule is checked, add the newer messages to
             // the list of messages to keep
