@@ -18,7 +18,7 @@ O2Requestor::O2Requestor(QNetworkAccessManager *manager, O2 *authenticator, QObj
         timedReplies_.setIgnoreSslErrors(authenticator->ignoreSslErrors());
     }
     qRegisterMetaType<QNetworkReply::NetworkError>("QNetworkReply::NetworkError");
-    connect(authenticator, SIGNAL(refreshFinished(QNetworkReply::NetworkError)), this, SLOT(onRefreshFinished(QNetworkReply::NetworkError)), Qt::QueuedConnection);
+    connect(authenticator, &O2::refreshFinished, this, &O2Requestor::onRefreshFinished, Qt::QueuedConnection);
 }
 
 O2Requestor::~O2Requestor()
@@ -33,7 +33,7 @@ int O2Requestor::get(const QNetworkRequest &req)
     reply_ = manager_->get(request_);
     timedReplies_.add(reply_);
     connect(reply_, SIGNAL(error(QNetworkReply::NetworkError)), this, SLOT(onRequestError(QNetworkReply::NetworkError)), Qt::QueuedConnection);
-    connect(reply_, SIGNAL(finished()), this, SLOT(onRequestFinished()), Qt::QueuedConnection);
+    connect(reply_, &QNetworkReply::finished, this, &O2Requestor::onRequestFinished, Qt::QueuedConnection);
     return id_;
 }
 
@@ -46,7 +46,7 @@ int O2Requestor::post(const QNetworkRequest &req, const QByteArray &data)
     reply_ = manager_->post(request_, data_);
     timedReplies_.add(reply_);
     connect(reply_, SIGNAL(error(QNetworkReply::NetworkError)), this, SLOT(onRequestError(QNetworkReply::NetworkError)), Qt::QueuedConnection);
-    connect(reply_, SIGNAL(finished()), this, SLOT(onRequestFinished()), Qt::QueuedConnection);
+    connect(reply_, &QNetworkReply::finished, this, &O2Requestor::onRequestFinished, Qt::QueuedConnection);
     connect(reply_, &QNetworkReply::uploadProgress, this, &O2Requestor::onUploadProgress);
     return id_;
 }
@@ -82,14 +82,18 @@ void O2Requestor::onRefreshFinished(QNetworkReply::NetworkError error)
 void O2Requestor::onRequestFinished()
 {
     QNetworkReply *senderReply = qobject_cast<QNetworkReply *>(sender());
-    QNetworkReply::NetworkError error = senderReply->error();
+#if (QT_VERSION < QT_VERSION_CHECK(5, 15, 0))
+    const auto networkError = senderReply->error();
+#else
+    const auto networkError = senderReply->networkError();
+#endif
     if (status_ == Idle) {
         return;
     }
     if (reply_ != senderReply) {
         return;
     }
-    if (error == QNetworkReply::NoError) {
+    if (networkError == QNetworkReply::NoError) {
         QTimer::singleShot(10, this, &O2Requestor::finish);
     }
 }
@@ -147,7 +151,7 @@ int O2Requestor::setup(const QNetworkRequest &req, QNetworkAccessManager::Operat
     url.addQueryItem(O2_OAUTH2_ACCESS_TOKEN, authenticator_->token());
 #else
     QUrlQuery query(url);
-    query.addQueryItem(O2_OAUTH2_ACCESS_TOKEN, authenticator_->token());
+    query.addQueryItem(QLatin1String(O2_OAUTH2_ACCESS_TOKEN), authenticator_->token());
     url.setQuery(query);
 #endif
     request_.setUrl(url);
@@ -185,7 +189,7 @@ void O2Requestor::retry()
     url.addQueryItem(O2_OAUTH2_ACCESS_TOKEN, authenticator_->token());
 #else
     QUrlQuery query(url);
-    query.addQueryItem(O2_OAUTH2_ACCESS_TOKEN, authenticator_->token());
+    query.addQueryItem(QLatin1String(O2_OAUTH2_ACCESS_TOKEN), authenticator_->token());
     url.setQuery(query);
 #endif
     request_.setUrl(url);
